import { createApiRef, createRouteRef, createPlugin, createApiFactory, configApiRef, discoveryApiRef, identityApiRef, createComponentExtension, createRoutableExtension } from '@backstage/core-plugin-api';
import { ResponseError } from '@backstage/errors';
import fetch from 'cross-fetch';
import pLimit from 'p-limit';

const fossaApiRef = createApiRef({
  id: "plugin.fossa.service"
});

var __defProp = Object.defineProperty;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __publicField = (obj, key, value) => {
  __defNormalProp(obj, typeof key !== "symbol" ? key + "" : key, value);
  return value;
};
class FossaClient {
  constructor({
    discoveryApi,
    identityApi,
    organizationId,
    externalLinkBaseUrl = "https://app.fossa.com"
  }) {
    __publicField(this, "discoveryApi");
    __publicField(this, "identityApi");
    __publicField(this, "organizationId");
    __publicField(this, "externalLinkBaseUrl");
    __publicField(this, "limit", pLimit(5));
    this.discoveryApi = discoveryApi;
    this.identityApi = identityApi;
    this.organizationId = organizationId;
    this.externalLinkBaseUrl = externalLinkBaseUrl;
  }
  async callApi(path, query) {
    const apiUrl = `${await this.discoveryApi.getBaseUrl("proxy")}/fossa`;
    const { token: idToken } = await this.identityApi.getCredentials();
    const response = await fetch(
      `${apiUrl}/${path}?${new URLSearchParams(query).toString()}`,
      {
        headers: idToken ? { Authorization: `Bearer ${idToken}` } : {}
      }
    );
    if (!response.ok) {
      throw await ResponseError.fromResponse(response);
    }
    return await response.json();
  }
  async *getProject(projectTitles) {
    const pageSize = 1e3;
    for (let page = 0; ; page++) {
      const projects = await this.limit(
        () => this.callApi("projects", {
          count: pageSize,
          page,
          sort: "title+",
          ...this.organizationId && {
            organizationId: this.organizationId
          },
          ...projectTitles.size === 1 && {
            title: projectTitles.values().next().value
          }
        })
      );
      for (const project of projects) {
        if (projectTitles.has(project.title) && project.revisions.length > 0) {
          const revision = project.revisions[0];
          yield {
            title: project.title,
            summary: {
              timestamp: revision.updatedAt,
              issueCount: revision.unresolved_licensing_issue_count || revision.unresolved_issue_count,
              dependencyCount: revision.dependency_count,
              projectDefaultBranch: project.default_branch,
              projectUrl: `${this.externalLinkBaseUrl}/projects/${encodeURIComponent(project.locator)}`
            }
          };
        }
      }
      if (projects.length < pageSize) {
        break;
      }
    }
  }
  async getFindingSummaries(projectTitles) {
    const map = /* @__PURE__ */ new Map();
    if (projectTitles.length === 0) {
      return map;
    }
    for await (const { title, summary } of this.getProject(
      new Set(projectTitles)
    )) {
      map.set(title, summary);
    }
    return map;
  }
  async getFindingSummary(projectTitle) {
    const summaries = await this.getFindingSummaries([projectTitle]);
    return summaries.get(projectTitle);
  }
}

const rootRoute = createRouteRef({
  id: "fossa-overview"
});

const fossaPlugin = createPlugin({
  id: "fossa",
  apis: [
    createApiFactory({
      api: fossaApiRef,
      deps: {
        configApi: configApiRef,
        discoveryApi: discoveryApiRef,
        identityApi: identityApiRef
      },
      factory: ({ configApi, discoveryApi, identityApi }) => new FossaClient({
        discoveryApi,
        identityApi,
        organizationId: configApi.getOptionalString("fossa.organizationId"),
        externalLinkBaseUrl: configApi.getOptionalString(
          "fossa.externalLinkBaseUrl"
        )
      })
    })
  ],
  routes: {
    fossaOverview: rootRoute
  }
});

const EntityFossaCard = fossaPlugin.provide(
  createComponentExtension({
    name: "EntityFossaCard",
    component: {
      lazy: () => import('./index-v6GgqDr3.esm.js').then((m) => m.FossaCard)
    }
  })
);
const FossaPage = fossaPlugin.provide(
  createRoutableExtension({
    name: "FossaPage",
    component: () => import('./index-DtTE9psW.esm.js').then((m) => m.FossaPage),
    mountPoint: rootRoute
  })
);

export { EntityFossaCard as E, FossaPage as F, fossaPlugin as a, fossaApiRef as f };
//# sourceMappingURL=index-BdHZx_Uy.esm.js.map
